openstack-cli-core 0.13.5

OpenStack CLI core
docs.rs failed to build openstack-cli-core-0.13.5
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: openstack-cli-core-0.13.6

OpenStack CLI core functionality