Module cli

Module cli 

CLI top level command and processing

Structs

CompletionCommand
Output shell completion code for the specified shell (bash, zsh, fish, or powershell). The shell code must be evaluated to provide interactive completion of osc commands. This can be done by sourcing it from the .bash_profile.
ConnectionOpts
Connection options.
GlobalOpts
Global CLI options.
OutputOpts
Output configuration.

Enums

OutputFormat
Output format.
TableArrangement
Table arrangement.

Traits

CliArgs
Trait for getting Command execution context.

Functions

parse_config
Parse config file
styles