pub struct ConnectionOpts {
pub os_cloud: Option<String>,
pub cloud_config_from_env: bool,
pub os_cloud_name: Option<String>,
pub os_project_id: Option<String>,
pub os_project_name: Option<String>,
pub os_region_name: Option<String>,
pub os_client_config_file: Option<String>,
pub os_client_secure_file: Option<String>,
pub auth_helper_cmd: Option<String>,
}Expand description
Connection options.
Fields
os_cloud: Option<String>Name reference to the clouds.yaml entry for the cloud configuration.
cloud_config_from_env: boolGet the cloud config from environment variables.
Conflicts with the --os-cloud option. No merging of environment variables with the
options from the clouds.yaml file done. It is possible to rely on the --auth-helper-cmd
command, but than the --os-cloud-name should be specified to give a reasonable connection
name.
os_cloud_name: Option<String>Cloud name used when configuration is retrieved from environment variables. When not
specified the envvars would be used as a default. This value will be used eventually by
the authentication helper when data need to be provided dynamically.
os_project_id: Option<String>Project ID to use instead of the one in connection profile.
os_project_name: Option<String>Project Name to use instead of the one in the connection profile.
os_region_name: Option<String>Region Name to use instead of the one in the connection profile.
os_client_config_file: Option<String>Custom path to the clouds.yaml config file.
os_client_secure_file: Option<String>Custom path to the secure.yaml config file.
auth_helper_cmd: Option<String>External authentication helper command.
Invoke external command to obtain necessary connection parameters. This is a path to the
executable, which is called with first parameter being the attribute key (i.e. password)
and a second parameter a cloud name (whatever is used in --os-cloud or
--os-cloud-name).