pub struct OutputProcessor {
pub config: Option<ViewConfig>,
pub target: OutputFor,
pub table_arrangement: TableArrangement,
pub fields: BTreeSet<String>,
pub wide: bool,
pub pretty: bool,
/* private fields */
}Expand description
Output Processor.
Fields
config: Option<ViewConfig>Resource output configuration
target: OutputForWhether output is for human or for machine
table_arrangement: TableArrangementTable arrangement
fields: BTreeSet<String>Fields requested
wide: boolWide mode
pretty: boolPretty mode
Implementations
Sourceimpl OutputProcessor
impl OutputProcessor
Sourcepub fn from_args<C: CliArgs, R: AsRef<str>, A: AsRef<str>>(
args: &C,
resource_key: Option<R>,
action: Option<A>,
) -> Self
pub fn from_args<C: CliArgs, R: AsRef<str>, A: AsRef<str>>( args: &C, resource_key: Option<R>, action: Option<A>, ) -> Self
Get OutputConfig from passed arguments
Sourcepub fn validate_args<C: CliArgs>(
&self,
_args: &C,
) -> Result<(), OpenStackCliError>
pub fn validate_args<C: CliArgs>( &self, _args: &C, ) -> Result<(), OpenStackCliError>
Validate command arguments with respect to the output producing
Sourcepub fn output_list<T>(&self, data: Vec<Value>) -> Result<(), OpenStackCliError>
pub fn output_list<T>(&self, data: Vec<Value>) -> Result<(), OpenStackCliError>
Output List of resources
Sourcepub fn output_single<T>(&self, data: Value) -> Result<(), OpenStackCliError>where
T: StructTable + DeserializeOwned,
pub fn output_single<T>(&self, data: Value) -> Result<(), OpenStackCliError>where
T: StructTable + DeserializeOwned,
Output List of resources
Sourcepub fn output_human<T: StructTable>(
&self,
data: &T,
) -> Result<(), OpenStackCliError>
pub fn output_human<T: StructTable>( &self, data: &T, ) -> Result<(), OpenStackCliError>
Produce output for humans (table) for a single resource
Sourcepub fn output_machine(&self, data: Value) -> Result<(), OpenStackCliError>
pub fn output_machine(&self, data: Value) -> Result<(), OpenStackCliError>
Produce output for machine Return machine readable output with the API side names
Sourcepub fn show_command_hint(&self) -> Result<(), OpenStackCliError>
pub fn show_command_hint(&self) -> Result<(), OpenStackCliError>
Show hints