CLI top level command and processing
Structs
- Completion
Command - Output shell completion code for the specified shell (bash, zsh, fish, or powershell). The
shell code must be evaluated to provide interactive completion of
osccommands. This can be done by sourcing it from the .bash_profile. - Connection
Opts - Connection options.
- Global
Opts - Global CLI options.
- Output
Opts - Output configuration.
Enums
- Output
Format - Output format.
- Table
Arrangement - Table arrangement.
Traits
- CliArgs
- Trait for getting Command execution context.
Functions
- parse_
config - Parse config file
- styles